# *__coding: UTF-8__*
import socket
import uuid

def getinfo():
    myip=socket.gethostbyname(socket.gethostname())
    print("本机IP地址是：:"+myip)
    node=uuid.getnode()
    mac=uuid.UUID(int=node).hex[-12:]
    print("本机Mac地址是："+mac)

def hello():
    return ('美味不用等欢迎你!!!')

if __name__ == '__main__':
    getinfo()



#my_module.py
# my_module模块

#这样在另外一个文件中用from my_module import *就这能导入列表中规定的两个名字
__all__=['money','read1']

print('from the my_module.py')

money=1000

def read1():
    print('my_module->read1->money',money)

def read2():
    print('my_module->read2 calling read1')
    read1()

def change():
    global money
    money=0



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='mwbyd',
    version='v1.0.11',
    author='kts168',
    author_email='kts168@163.com',
    description="美味不用等",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://github.com/kts168/mwbyd",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)